using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;


namespace GGCComboBoxDemo
{
	/// <summary>
	/// Summary description for Form1.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		private Syncfusion.Windows.Forms.Grid.Grouping.GridGroupingControl gridLimits;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private DataTable myVF;

		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			//
			// TODO: Add any constructor code after InitializeComponent call
			//

			gridLimits.DataSource = CreateLimitsTable();
			DataTable dt = CreateEventFrequencies();
			gridLimits.SourceListSet.Add("EventFrequencies", dt);
			myVF = CreateValidDurationView();
			gridLimits.SourceListSet.Add("CalculationDurations", myVF);
			
			GridTableDescriptor LimitsTd = gridLimits.TableDescriptor;
	
			GridRelationDescriptor EventFrequencyRd = new GridRelationDescriptor();
			EventFrequencyRd.Name = "EventFrequencies";
			EventFrequencyRd.RelationKind = RelationKind.ForeignKeyReference;
			EventFrequencyRd.ChildTableName = "EventFrequencies";  // SourceListSet name for lookup
			EventFrequencyRd.RelationKeys.Add("EventFrequencyId", "Id");
			EventFrequencyRd.ChildTableDescriptor.VisibleColumns.Add("Frequency");
			LimitsTd.Relations.Add(EventFrequencyRd);

			GridRelationDescriptor CalculationDurationRd = new GridRelationDescriptor();
			CalculationDurationRd.Name = "CalculationDurations";
			CalculationDurationRd.RelationKind = RelationKind.ForeignKeyReference;
			CalculationDurationRd.ChildTableName = "CalculationDurations";  // SourceListSet name for lookup
			CalculationDurationRd.RelationKeys.Add("CalculationDurationId", "CalculationDurationId");
			CalculationDurationRd.ChildTableDescriptor.VisibleColumns.Add("DurationType");
			LimitsTd.Relations.Add(CalculationDurationRd);

			LimitsTd.VisibleColumns.Remove("Id");
			LimitsTd.VisibleColumns.Remove("CalculationDurations_EventFrequencyId");

			gridLimits.TopLevelGroupOptions.ShowCaption = false;
			this.gridLimits.TableControlCurrentCellShowingDropDown += new GridTableControlCurrentCellShowingDropDownEventHandler(gridLimits_TableControlCurrentCellShowingDropDown);
		}

		//used to immediately commit changes in the master cell
		private void gridLimits_CurrentCellChanged(object sender, EventArgs e)
		{
			
		}
		
		private void gridLimits_TableControlCurrentCellShowingDropDown(object sender, GridTableControlCurrentCellShowingDropDownEventArgs e)
		{
			try
			{
				
				GridTableDescriptor LimitsTd = e.TableControl.TableDescriptor;
				int durIdx = LimitsTd.VisibleColumns.IndexOf("CalculationDurations_DurationType")+1;
			
				if (e.TableControl.CurrentCell.ColIndex == durIdx)
				{
					string frequencyId = this.gridLimits.Table.CurrentRecord.GetValue("EventFrequencyId").ToString();
					myVF.DefaultView.RowFilter = string.Format("[EventFrequencyId] <= '{0}'", frequencyId); 
				}
			}
			catch
			{
				e.Inner.Cancel = true; 
			}
			 
			
		}

		private DataTable CreateLimitsTable() 
		{
			DataTable dt = new DataTable();
    
			dt.TableName = "HF_Limits";
			
			DataRow dr;
			dt.Columns.Add("Id", typeof(int));
			dt.Columns.Add("EventFrequencyId", typeof(int));
			dt.Columns.Add("CalculationDurationId", typeof(int));
			for(int row =2;row <= 3 ; row++)
			{
			
				dr = dt.NewRow();	
				dr["Id"] = row-1;
				dr["EventFrequencyId"] = row;
				dr["CalculationDurationId"] = row-1;
				dt.Rows.Add(dr);
			} 
			return dt;
		}

		private DataTable CreateEventFrequencies() 
		{
			DataTable dt = new DataTable();
    
			dt.TableName = "EventFrequencies";
			
			DataRow dr;
			dt.Columns.Add("Id", typeof(int));
			dt.Columns.Add("Frequency", typeof(string));
			dr = dt.NewRow();	
			dr["Id"] = 1;
			dr["Frequency"] = "Monthly";
			dt.Rows.Add(dr);

			dr = dt.NewRow();	
			dr["Id"] = 2;
			dr["Frequency"] = "Qtrly";
			dt.Rows.Add(dr);

			dr = dt.NewRow();	
			dr["Id"] = 3;
			dr["Frequency"] = "Annual";
			dt.Rows.Add(dr);

			return dt;
		}

		private DataTable CreateValidDurationView() 
		{
			DataTable dt = new DataTable();
    
			dt.TableName = "ValidFrequencies";
			
			DataRow dr;
			dt.Columns.Add("EventFrequencyId", typeof(int));
			dt.Columns.Add("CalculationDurationId", typeof(int));
			dt.Columns.Add("DurationType", typeof(string));
			//for(int row =1;row <=3 ; row++)
			{
				for(int col =1;col <= 3 ; col++)
				{
			
					dr = dt.NewRow();	
					dr["EventFrequencyId"] = col;
					dr["CalculationDurationId"] = col;
					if (col == 1)
						dr["DurationType"] = "< Month";
					else if (col == 2)
						dr["DurationType"] = "< Qtr";
					else
						dr["DurationType"] = "< Year";
					dt.Rows.Add(dr);
				}
			} 
			
			return dt;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}



		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.gridLimits = new Syncfusion.Windows.Forms.Grid.Grouping.GridGroupingControl();
			((System.ComponentModel.ISupportInitialize)(this.gridLimits)).BeginInit();
			this.SuspendLayout();
			// 
			// gridLimits
			// 
			this.gridLimits.BackColor = System.Drawing.SystemColors.Window;
			this.gridLimits.Location = new System.Drawing.Point(16, 24);
			this.gridLimits.Name = "gridLimits";
			this.gridLimits.Size = new System.Drawing.Size(640, 328);
			this.gridLimits.TabIndex = 0;
			this.gridLimits.Text = "gridGroupingControl1";
			this.gridLimits.VersionInfo = "3.301.0.11";
			this.gridLimits.TableControlCurrentCellShowedDropDown += new Syncfusion.Windows.Forms.Grid.Grouping.GridTableControlEventHandler(this.gridLimits_TableControlCurrentCellShowedDropDown);
			this.gridLimits.TableControlCurrentCellActivating += new Syncfusion.Windows.Forms.Grid.Grouping.GridTableControlCurrentCellActivatingEventHandler(this.gridLimits_TableControlCurrentCellActivating);
			this.gridLimits.TableControlCurrentCellCloseDropDown += new Syncfusion.Windows.Forms.Grid.Grouping.GridTableControlPopupClosedEventHandler(this.gridLimits_TableControlCurrentCellCloseDropDown);
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(680, 390);
			this.Controls.Add(this.gridLimits);
			this.Name = "Form1";
			this.Text = "Form1";
			((System.ComponentModel.ISupportInitialize)(this.gridLimits)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}

		private void gridLimits_TableControlCurrentCellShowedDropDown(object sender, Syncfusion.Windows.Forms.Grid.Grouping.GridTableControlEventArgs e)
		{
				
		}

		private void gridLimits_TableControlCurrentCellActivating(object sender, Syncfusion.Windows.Forms.Grid.Grouping.GridTableControlCurrentCellActivatingEventArgs e)
		{
			try
			{
				
				GridTableDescriptor LimitsTd = e.TableControl.TableDescriptor;
				int durIdx = LimitsTd.VisibleColumns.IndexOf("CalculationDurations_DurationType")+1;
			
				if (e.Inner.RowIndex > 2 && e.Inner.ColIndex == durIdx)
				{
					string frequencyId = gridLimits.Table.Records[e.Inner.RowIndex - 3].GetValue("EventFrequencyId").ToString();
					myVF.DefaultView.RowFilter = string.Format("[EventFrequencyId] <= '{0}'", frequencyId);
					
				}
			}
			catch(Exception ex)
			{
				Console.WriteLine(ex.Message);  
			}
		}

		private void gridLimits_TableControlCurrentCellCloseDropDown(object sender, Syncfusion.Windows.Forms.Grid.Grouping.GridTableControlPopupClosedEventArgs e)
		{
			
		}
	}
}
